Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH i-g-t] tests/xe_eudebug: add basic-vm-access-parameters-userptr
@ 2024-12-19 13:39 Mika Kuoppala
  2024-12-19 13:47 ` Piatkowski, Dominik Karol
                   ` (5 more replies)
  0 siblings, 6 replies; 7+ messages in thread
From: Mika Kuoppala @ 2024-12-19 13:39 UTC (permalink / raw)
  To: igt-dev
  Cc: Mika Kuoppala, Dominik Grzegorzek, Christoph Manszewski,
	Andrzej Hajda, Dominik Karol Piątkowski

There is an easy way to also use the access-parameters test
to be based on userptr backing storage. Make it so.

Cc: Dominik Grzegorzek <dominik.grzegorzek@intel.com>
Cc: Christoph Manszewski <christoph.manszewski@intel.com>
Cc: Andrzej Hajda <andrzej.hajda@intel.com>
Cc: Dominik Karol Piątkowski <dominik.karol.piatkowski@intel.com>
Signed-off-by: Mika Kuoppala <mika.kuoppala@linux.intel.com>
---
 tests/intel/xe_eudebug.c | 11 ++++++++++-
 1 file changed, 10 insertions(+), 1 deletion(-)

diff --git a/tests/intel/xe_eudebug.c b/tests/intel/xe_eudebug.c
index d9281f78f..dc8e587b7 100644
--- a/tests/intel/xe_eudebug.c
+++ b/tests/intel/xe_eudebug.c
@@ -1773,7 +1773,13 @@ static void vm_trigger_access_parameters(struct xe_eudebug_debugger *d,
 /**
  * SUBTEST: basic-vm-access-parameters
  * Description:
  *      Check negative scenarios of VM_OPEN ioctl and pread/pwrite usage.
  */
 static void test_vm_access_parameters(int fd, unsigned int flags, int num_clients)
 {
@@ -2830,6 +2836,9 @@ igt_main
 	igt_subtest("basic-vm-access-parameters")
 		test_vm_access_parameters(fd, 0, 1);
 
+	igt_subtest("basic-vm-access-parameters-userptr")
+		test_vm_access_parameters(fd, VM_BIND_OP_MAP_USERPTR, 1);
+
 	igt_subtest("multiple-sessions")
 		test_basic_sessions(fd, CREATE_VMS | CREATE_EXEC_QUEUES, 4, true);
 
@@ -1773,7 +1773,13 @@ static void vm_trigger_access_parameters(struct xe_eudebug_debugger *d,
  * SUBTEST: basic-vm-access-parameters
  * Description:
- *      Check negative scenarios of VM_OPEN ioctl and pread/pwrite usage.
+ *      Check negative scenarios of VM_OPEN ioctl and pread/pwrite usage
+ *      with bo backing storage.
+ *
+ * SUBTEST: basic-vm-access-parameters-userptr
+ * Description:
+ *      Check negative scenarios of VM_OPEN ioctl and pread/pwrite usage
+ *      with userptr backing storage.
  */
 static void test_vm_access_parameters(int fd, unsigned int flags, int num_clients)
-- 
2.43.0


^ permalink raw reply related	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2024-12-20 15:17 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-12-19 13:39 [PATCH i-g-t] tests/xe_eudebug: add basic-vm-access-parameters-userptr Mika Kuoppala
2024-12-19 13:47 ` Piatkowski, Dominik Karol
2024-12-19 16:06 ` ✗ GitLab.Pipeline: warning for " Patchwork
2024-12-19 16:28 ` ✓ i915.CI.BAT: success " Patchwork
2024-12-19 16:49 ` ✓ Xe.CI.BAT: " Patchwork
2024-12-20 11:49 ` ✗ i915.CI.Full: failure " Patchwork
2024-12-20 15:17 ` ✗ Xe.CI.Full: " Patchwork

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox